/*
 *    snake - a videogame derived from Q-Basic nibbles
 *    Copyright (C) 1999 Cyberandro J.K. Starrik
 *
 *    This program is free software; you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation; either version 2 of the License, or
 *    (at your option) any later version.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with this program; if not, write to the Free Software
 *    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 */

/*
 * file: ui_vga.c *  purpose: handle vga graphics 
 */

#include "snake.h"
#include <vga.h>

#define ARENA_X_OFFSET 1
#define ARENA_Y_OFFSET 1

#define VMODE 1

/* public functions */
int init_graphics (void);
void finish_graphics (void);
void draw_arena (ARENA *);
void draw_message (char *);
void updatescreen (void);
char *prompt (char *);
int getkey (void);

/* private functions */
static void draw_borders(int xdim, int ydim);

/* public data */
int screen_initialized = 0;

/* initialize the graphics */
int
init_graphics ()
{

  int xdim, ydim;

  /* initialize vga screen */
  vga_init();
  vga_setmode(VMODE);

  xdim = vga_getxdim();
  ydim = vga_getydim();

  /* Set arena dimensions if not already set */
  if ( ! arena.lines ) arena.lines = ydim-2;
  if ( ! arena.cols ) arena.cols = xdim-2;

  /* Check arena dimensions fitness */
  if ( arena.lines > ydim-2 || arena.cols > xdim-2 )
  {
    message("Arena size (%i,%i) out of screen boundary (%i,%i)",
            arena.lines, arena.cols, ydim-2, xdim-2);
    finish();
  }

  draw_borders(arena.cols+2, arena.lines+2);

  /* Set screen initialized flag */
  screen_initialized = 1;

  return 1;

}

/* vga version of message drawing function */
void
draw_message (char *str)
{
  return;
}

/* arena drawing */
void
draw_arena (ARENA *arena)
{
  int y, x;
  sprite *sp;
  int look;

  for (y = 0; y < arena->lines; y++)
  {
    for (x = 0; x < arena->cols; x++)
    {
      sp = GETSPRITE(arena,y,x);
      if (sp) switch (sp->type)
      {
        case SNAKE:
          look = 6;
          break;  
        case EXSNAKE:
          look = 1;
          break; 
        case FRUIT:
          look = 3;
          break;
        case WALL:
          look = 1;
          break;
        default:
          look = 0;
          break;
      }
      else look = 0;
      vga_setcolor(look);
	    vga_drawpixel(x+ARENA_X_OFFSET, y+ARENA_Y_OFFSET);
      vga_setcolor(7);
    }
  }
}


/*
 * update the screen 
 */
void
updatescreen ()
{
/*
  static int motionidx=0;
  vga_drawpixel(0, motionidx++);
*/
}

void
finish_graphics ()
{
}


/*
 * Get next key in input buffer
 */
int
getkey ()
{
  int ret;
  
  ret=vga_getkey();
  if (!ret) return -1;
  return ret;
}

/*
 * prompt the user for a string
 * the line returnered is allocated with malloc(3)
 * so the caller must free it when finished with it. 
 */
char *
prompt (char *prompt_string)
{
  return NULL;
}

/************ PRIVATE FUNCTIONS **********************/

static void
draw_borders (int xdim, int ydim)
{
	vga_drawline(0,0,0,ydim-1);
	vga_drawline(xdim-1,0,xdim-1,ydim-1);
	vga_drawline(0,0,xdim-1,0);
	vga_drawline(0,ydim-1,xdim-1,ydim-1);
}
